@@ -4,43 +4,42 @@ OC.L10N.register(
     "Details" : "Detalii",
     "All contacts" : "Toate contactele",
     "Contacts" : "Contacte",
-    "Loading contacts …" : "Se încarcă contactele ...",
-    "Loading …" : "Se încarcă…",
     "Rename" : "Redenumește",
     "Send email" : "Trimite email-ul",
     "Delete" : "Șterge",
+    "Recently contacted" : "Contactat recent",
     "Copied" : "Copiat",
     "Copy link" : "Copiază linkul",
     "Download" : "Descărcare",
     "Share with users or groups" : "Partajează cu utilizatori sau grupuri",
     "No users or groups" : "Nu sunt utilizatori sau grupuri",
     "can edit" : "poate edita",
+    "Cancel" : "Anulează",
     "Add" : "Add",
     "First name" : "Prenume",
     "Last name" : "Nume",
     "Display name" : "Nume afișat",
     "Save" : "Salvează",
-    "Cancel" : "Anulează",
+    "Close" : "Închide",
+    "Create" : "Creează",
     "Invalid image" : "Imagine invalidă",
     "Address book" : "Listă de contacte",
     "Name" : "Nume",
     "Title" : "Titlu",
     "Company" : "Companie",
-    "Search contacts …" : "Caută contacte ...",
+    "Move" : "Move",
     "No results" : "Niciun rezultat",
     "Pending" : "În așteptare",
     "None" : "Niciuna",
     "Select option" : "Selectatți opțiunea",
+    "Member" : "Membru",
     "New contact" : "Contact nou ",
-    "Close" : "Închide",
     "Import" : "Importă",
     "Not grouped" : "Negrupate",
-    "Recently contacted" : "Contactat recent",
     "User" : "Utilizator",
     "Group" : "Grup",
     "Email" : "Email",
     "Contact" : "Contact",
-    "Member" : "Membru",
     "Moderator" : "Moderator",
     "Admin" : "Admin",
     "Owner" : "Proprietar",
@@ -93,9 +92,8 @@ OC.L10N.register(
     "Female" : "Femeie",
     "Male" : "Bărbat",
     "Unknown" : "Necunoscut",
-    "Password protection" : "Protecție parolă ",
-    "Description" : "Descriere",
-    "Settings" : "Settings",
-    "Visibility" : "Vizibil"
+    "Loading contacts …" : "Se încarcă contactele ...",
+    "Loading …" : "Se încarcă…",
+    "Search contacts …" : "Caută contacte ..."
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
